package com.flossom.system.service;


import com.flossom.common.core.domain.entity.WxNursingLog;
import com.flossom.common.core.domain.req.UserNursingLogReq;

import java.util.List;

/**
 * 用户护理日志Service接口
 *
 * @author flossom
 * @date 2024-02-21
 */
public interface IWxNursingLogService {

    /**
     * 查询用户护理日志
     *
     * @param id 用户护理日志主键
     * @return 用户护理日志
     */
    public WxNursingLog selectWxNursingLogById(Long id);

    /**
     * 查询用户护理日志列表
     *
     * @param wxNursingLog 用户护理日志
     * @return 用户护理日志集合
     */
    public List<WxNursingLog> selectWxNursingLogList(UserNursingLogReq wxNursingLog, boolean isPage);

    /**
     * 新增用户护理日志
     *
     * @param wxNursingLog 用户护理日志
     * @return 结果
     */
    public int insertWxNursingLog(WxNursingLog wxNursingLog);

    /**
     * 修改用户护理日志
     *
     * @param wxNursingLog 用户护理日志
     * @return 结果
     */
    public int updateWxNursingLog(WxNursingLog wxNursingLog);

    /**
     * 批量删除用户护理日志
     *
     * @param ids 需要删除的用户护理日志主键集合
     * @return 结果
     */
    public int deleteWxNursingLogByIds(Long[] ids);

    /**
     * 删除用户护理日志信息
     *
     * @param id 用户护理日志主键
     * @return 结果
     */
    public int deleteWxNursingLogById(Long id);

    List<WxNursingLog> selectWxNursingLogByIdList(List<Integer> idList);

}
